Python Environment
==================

Python is needed in version 3.9 or higher, it can be obtained
`here <https://www.python.org/downloads/>`__ 

It is strongly recommended
to create a python virtual environment (venv) as described
`here <https://docs.python.org/3/library/venv.html>`__

After creating the virtual environment you should install pysdc as a
package:

::

    pip install sdc11073

If you want to use the package from source you could use the following in the root folder of the repo
::

    pip install -e .

